package pwp;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class Record {

    private int wins;
    private int losses;
    private int draws;

    public static Record fromEvents(Collection<Event> events) {
        List<Match> matches = new ArrayList<>();

        for (Event event : events) {
            matches.addAll(event.getMatches());
        }

        return new Record(matches);
    }

    public static Record fromMatches(Collection<Match> matches) {
        return new Record(matches);
    }

    private Record(Collection<Match> matches) {
        wins = 0;
        losses = 0;
        draws = 0;

        for (Match m : matches) {
            switch (m.getOutcome()) {
                case WIN:  wins++;   break;
                case LOSS: losses++; break;
                case DRAW: draws++;  break;
            }
        }
    }

    public String toString() {
        return (draws == 0)
            ? wins + "-" + losses
            : wins + "-" + losses + "-" + draws;
    }

    public double winPercentageWithoutDraws() {
        return 100 * (((double) wins) / ((double) (wins + losses)));
    }

    public double winPercentageWithDraws() {
        return 100 * (((double) wins) / ((double) (wins + losses + draws)));
    }

    public int getWins() {
        return wins;
    }

    public int getLosses() {
        return losses;
    }

    public int getDraws() {
        return draws;
    }
}
